@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2020                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef COMPONENT_H
 #define COMPONENT_H
@@ -36,7 +31,7 @@ public:
     void saveToXMI1(QXmlStreamWriter& writer);
 
     void setExecutable(bool executable);
-    bool getExecutable();
+    bool getExecutable() const;
 
 protected:
     bool load1(QDomElement & element);
